@@ -273,7 +273,17 @@ fr_command_cfile_add (FrCommand     *comm,
 		fr_process_end_command (comm->process);
 		compressed_filename = g_strconcat (filename, ".xz", NULL);
 	}
-	else if (is_mime_type (comm->mime_type, "application/x-zstd")) {
+	else if (is_mime_type (comm->mime_type, "application/x-lz4")) {
+		compressed_filename = g_strconcat (filename, ".lz4", NULL);
+		fr_process_begin_command (comm->process, "lz4");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-z");
+		fr_process_add_arg (comm->process, filename);
+		fr_process_add_arg (comm->process, compressed_filename);
+		fr_process_end_command (comm->process);
+	}
+	else if (is_mime_type (comm->mime_type, "application/zstd")) {
 		fr_process_begin_command (comm->process, "zstd");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "--");
@@ -364,6 +374,8 @@ fr_command_cfile_extract (FrCommand  *comm,
 
 	/* uncompress the file */
 
+	uncompr_file = remove_extension_from_path (temp_file);
+
 	if (is_mime_type (comm->mime_type, "application/gzip")) {
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_add_arg (comm->process, "-f");
@@ -412,13 +424,22 @@ fr_command_cfile_extract (FrCommand  *comm,
 		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
 	}
-	else if (is_mime_type (comm->mime_type, "application/x-zstd")) {
+	else if (is_mime_type (comm->mime_type, "application/zstd")) {
 		fr_process_begin_command (comm->process, "zstd");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
 		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
 	}
+	else if (is_mime_type (comm->mime_type, "application/x-lz4")) {
+		fr_process_begin_command (comm->process, "lz4");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-d");
+		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, uncompr_file);
+		fr_process_end_command (comm->process);
+	}
 	else if (is_mime_type (comm->mime_type, "application/x-lzop")) {
 		fr_process_begin_command (comm->process, "lzop");
 		fr_process_set_working_dir (comm->process, temp_dir);
@@ -438,8 +459,6 @@ fr_command_cfile_extract (FrCommand  *comm,
 
 	/* copy uncompress file to the dest dir */
 
-	uncompr_file = remove_extension_from_path (temp_file);
-
 	compr_file = get_uncompressed_name_from_archive (comm, comm->filename);
 	if (compr_file == NULL)
 		compr_file = remove_extension_from_path (file_name_from_path (comm->filename));
@@ -478,7 +497,8 @@ const char *cfile_mime_type[] = { "application/gzip",
 				  "application/x-lzop",
 				  "application/x-rzip",
 				  "application/x-xz",
-				  "application/x-zstd",
+				  "application/zstd",
+				  "application/x-lz4",
 				  NULL };
 
 
@@ -523,10 +543,14 @@ fr_command_cfile_get_capabilities (FrCommand  *comm,
 		if (is_program_available ("xz", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
-	else if (is_mime_type (mime_type, "application/x-zstd")) {
+	else if (is_mime_type (mime_type, "application/zstd")) {
 		if (is_program_available ("zstd", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
+	else if (is_mime_type (mime_type, "application/x-lz4")) {
+		if (is_program_available ("lz4", check_command))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
 	else if (is_mime_type (mime_type, "application/x-lzop")) {
 		if (is_program_available ("lzop", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
@@ -568,8 +592,10 @@ fr_command_cfile_get_packages (FrCommand  *comm,
 		return PACKAGES ("lzma");
 	else if (is_mime_type (mime_type, "application/x-xz"))
 		return PACKAGES ("xz");
-	else if (is_mime_type (mime_type, "application/x-zstd"))
+	else if (is_mime_type (mime_type, "application/zstd"))
 		return PACKAGES ("zstd");
+	else if (is_mime_type (mime_type, "application/x-lz4"))
+		return PACKAGES ("lz4");
 	else if (is_mime_type (mime_type, "application/x-lzop"))
 		return PACKAGES ("lzop");
 	else if (is_mime_type (mime_type, "application/x-rzip"))
