@@ -85,6 +85,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-lha",                  ".lzh",      N_("Lha (.lzh)"), 0 },
 	{ "application/x-lrzip",                ".lrz",      N_("Lrzip (.lrz)"), 0},
 	{ "application/x-lrzip-compressed-tar", ".tar.lrz",  N_("Tar compressed with lrzip (.tar.lrz)"), 0 },
+	{ "application/x-lz4",                  ".lz4",      N_("LZ4 compressed file (.lz4)"), 0 },
+	{ "application/x-lz4-compressed-tar",   ".tar.lz4",  N_("Tar compressed with lz4 (.tar.lz4)"), 0 },
 	{ "application/x-lzip",                 ".lz",       NULL, 0 },
 	{ "application/x-lzip-compressed-tar",  ".tar.lz",   N_("Tar compressed with lzip (.tar.lz)"), 0 },
 	{ "application/x-lzma",                 ".lzma",     NULL, 0 },
@@ -102,8 +104,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-war",                  ".war",      N_("War (.war)"), 0 },
 	{ "application/x-xz",                   ".xz",       N_("Xz (.xz)"), 0 },
 	{ "application/x-xz-compressed-tar",    ".tar.xz",   N_("Tar compressed with xz (.tar.xz)"), 0 },
-	{ "application/x-zstd",                 ".zst",      N_("Zstandard compressed file"), 0 },
-	{ "application/x-zstd-compressed-tar",  ".tar.zst",  N_("Tar compressed with zstd"), 0 },
+	{ "application/zstd",                   ".zst",      N_("Zstandard compressed file (.zst)"), 0 },
+	{ "application/x-zstd-compressed-tar",  ".tar.zst",  N_("Tar compressed with zstd (.tar.zst)"), 0 },
 	{ "application/x-zoo",                  ".zoo",      N_("Zoo (.zoo)"), 0 },
 	{ "application/zip",                    ".zip",      N_("Zip (.zip)"), 0 },
 	{ "application/vnd.android.package-archive", ".apk", NULL, 0 },
@@ -137,6 +139,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".lrz", "application/x-lrzip" },
 	{ ".lzh", "application/x-lha" },
 	{ ".lz", "application/x-lzip" },
+	{ ".lz4", "application/x-lz4" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
 	{ ".rar", "application/vnd.rar" },
@@ -144,11 +147,14 @@ FrExtensionType file_ext_type[] = {
 	{ ".rz", "application/x-rzip" },
 	{ ".sit", "application/x-stuffit" },
 	{ ".swm", "application/x-ms-wim" },
+	{ ".xz", "application/x-xz" },
+	{ ".zst", "application/zstd" },
 	{ ".tar", "application/x-tar" },
 	{ ".tar.bz2", "application/x-bzip2-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
 	{ ".tar.lrz", "application/x-lrzip-compressed-tar" },
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
+	{ ".tar.lz4", "application/x-lz4-compressed-tar" },
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
 	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
 	{ ".tar.7z", "application/x-7z-compressed-tar" },
@@ -161,12 +167,11 @@ FrExtensionType file_ext_type[] = {
 	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tzst", "application/x-zstd-compressed-tar" },
 	{ ".tlz", "application/x-lzip-compressed-tar" },
+	{ ".tlz4", "application/x-lz4-compressed-tar" },
 	{ ".tzma", "application/x-lzma-compressed-tar" },
 	{ ".tzo", "application/x-lzop-compressed-tar" },
 	{ ".war", "application/x-war" },
 	{ ".wim", "application/x-ms-wim" },
-	{ ".xz", "application/x-xz" },
-	{ ".zst", "application/x-zstd" },
 	{ ".z", "application/gzip" },
 	{ ".Z", "application/x-compress" },
 	{ ".zip", "application/zip" },
