@@ -69,6 +69,12 @@ MainWindow::MainWindow(QWidget* parent):
 
     loadSettings();
 
+    // use a label instead of QStatusBar::showMessage to make messages permanent
+    QLabel* label = new QLabel();
+    label->setFocusPolicy(Qt::NoFocus);
+    label->setContentsMargins(4, 0, 4, 0);
+    ui_->statusBar->addWidget(label);
+
     // create a progress bar in the status bar
     progressBar_ = new QProgressBar{ui_->statusBar};
     ui_->statusBar->addPermanentWidget(progressBar_);
@@ -505,7 +511,7 @@ void MainWindow::on_actionExtract_triggered(bool /*checked*/) {
             archiver_->extractAll(dirUrl.toEncoded().constData(),
                                   dlg.skipOlder(),
                                   dlg.overwrite(),
-                                  dlg.reCreateFolders(),
+                                  !dlg.reCreateFolders(),
                                   password_.empty() ? nullptr : password_.c_str());
         }
         else {
@@ -521,7 +527,7 @@ void MainWindow::on_actionExtract_triggered(bool /*checked*/) {
                                     currentDirPath_.c_str(),
                                     dlg.skipOlder(),
                                     dlg.overwrite(),
-                                    dlg.reCreateFolders(),
+                                    !dlg.reCreateFolders(),
                                     password_.empty() ? nullptr : password_.c_str()
             );
         }
@@ -658,13 +664,13 @@ void MainWindow::onDragStarted() {
             mimeData->setUrls(urlList);
             drag->setMimeData(mimeData);
             if(files.empty()) { // all files are already extracted
-                if(drag->exec(Qt::CopyAction) == Qt::IgnoreAction) {
+                if(drag->exec(Qt::CopyAction) == Qt::IgnoreAction && drag) {
                     drag->deleteLater();
                 }
             }
             else { // wait until all files are extracted
                 connect(archiver_.get(), &Archiver::finish, drag, [drag]() {
-                    if(drag->exec(Qt::CopyAction) == Qt::IgnoreAction) {
+                    if(drag->exec(Qt::CopyAction) == Qt::IgnoreAction && drag) {
                         drag->deleteLater();
                     }
                 });
@@ -725,10 +731,16 @@ void MainWindow::on_actionDirTree_toggled(bool checked) {
 
 void MainWindow::on_actionDirTreeMode_toggled(bool /*checked*/) {
     setViewMode(ViewMode::DirTree);
+    // Reset:
+    ui_->actionDelete->setEnabled(false);
+    ui_->actionView->setEnabled(false);
 }
 
 void MainWindow::on_actionFlatListMode_toggled(bool /*checked*/) {
     setViewMode(ViewMode::FlatList);
+    // Reset:
+    ui_->actionDelete->setEnabled(false);
+    ui_->actionView->setEnabled(false);
 }
 
 void MainWindow::on_actionReload_triggered(bool /*checked*/) {
@@ -737,6 +749,9 @@ void MainWindow::on_actionReload_triggered(bool /*checked*/) {
             QDir(tempDir_).removeRecursively();
         }
         password_.clear();
+        if(auto label = ui_->statusBar->findChild<QLabel*>()) {
+            label->clear();
+        }
         archiver_->reloadArchive(nullptr);
     }
 }
@@ -768,17 +783,39 @@ void MainWindow::onDirTreeSelectionChanged(const QItemSelection& /*selected*/, c
         // expand the node as needed
         ui_->dirTreeView->expand(idx);
     }
+
+    // Reset:
+    ui_->actionDelete->setEnabled(false);
+    ui_->actionView->setEnabled(false);
 }
 
 void MainWindow::onFileListSelectionChanged(const QItemSelection& /*selected*/, const QItemSelection& /*deselected*/) {
+    if(archiver_->isLoaded() && !archiver_->isBusy()) {
+        if(auto selModel = ui_->fileListView->selectionModel()) {
+            ui_->actionDelete->setEnabled(selModel->hasSelection());
+            bool hasFile = false;
+            const QModelIndexList indexes = selModel->selectedRows();
+            for(const auto index : indexes) {
+                auto item = itemFromIndex(index);
+                if(item && !item->isDir()) {
+                    hasFile = true;
+                    break;
+                }
+            }
+            ui_->actionView->setEnabled(hasFile);
+        }
+        else {
+            ui_->actionDelete->setEnabled(false);
+            ui_->actionView->setEnabled(false);
+        }
+    }
+    else {
+        ui_->actionDelete->setEnabled(false);
+        ui_->actionView->setEnabled(false);
+    }
 }
 
 void MainWindow::onFileListContextMenu(const QPoint &pos) {
-    if(auto selModel = ui_->fileListView->selectionModel()) {
-        QModelIndex idx = selModel->currentIndex();
-        auto item = itemFromIndex(idx);
-        ui_->actionView->setVisible(item && !item->isDir());
-    }
     // QAbstractScrollArea and its subclasses map the context menu event to coordinates of the viewport().
     auto globalPos = ui_->fileListView->viewport()->mapToGlobal(pos);
     popupMenu_->popup(globalPos);
@@ -966,6 +1003,9 @@ void MainWindow::onActionFinished(FrAction action, ArchiverError err) {
             }
             Fm::FileLauncher().launchPaths(this, std::move(paths));
         }
+        else {
+            password_.clear(); // the password may have been wrong
+        }
         launchPaths_.clear();
         break;
     case FR_ACTION_COPYING_FILES_TO_REMOTE:    /* copying extracted files to a remote location */
@@ -982,7 +1022,9 @@ void MainWindow::onActionFinished(FrAction action, ArchiverError err) {
 }
 
 void MainWindow::onMessage(QString message) {
-    ui_->statusBar->showMessage(message);
+    if(auto label = ui_->statusBar->findChild<QLabel*>()) {
+        label->setText(message);
+    }
 }
 
 void MainWindow::onStoppableChanged(bool stoppable) {
@@ -1099,7 +1141,9 @@ void MainWindow::showFileList(const std::vector<const ArchiverItem *> &files) {
 
     proxyModel_->setSourceModel(model);
 
-    ui_->statusBar->showMessage(tr("%n file(s)", "", files.size()));
+    if(auto label = ui_->statusBar->findChild<QLabel*>()) {
+        label->setText(tr("%n file(s)", "", files.size()));
+    }
 
     fitFileViewColumns();
 }
@@ -1146,6 +1190,7 @@ void MainWindow::setBusyState(bool busy) {
 void MainWindow::updateUiStates() {
     bool hasArchive = archiver_->isLoaded();
     bool inProgress = archiver_->isBusy();
+    ui_->actionStop->setEnabled(inProgress);
 
     bool canLoad = !hasArchive || !inProgress;
     ui_->actionCreateNew->setEnabled(canLoad);
@@ -1169,9 +1214,11 @@ void MainWindow::updateUiStates() {
 
     ui_->actionAddFiles->setEnabled(canEdit);
     ui_->actionAddFolder->setEnabled(canEdit);
-    ui_->actionDelete->setEnabled(canEdit);
 
     ui_->actionExtract->setEnabled(canEdit);
+
+    // see onFileListSelectionChanged
+    onFileListSelectionChanged(QItemSelection(), QItemSelection());
 }
 
 std::vector<const FileData*> MainWindow::selectedFiles(bool recursive) {
@@ -1329,11 +1376,14 @@ void MainWindow::chdir(const ArchiverItem *dir) {
     auto dirTreeModel = ui_->dirTreeView->model();
     if(dirTreeModel) {
         auto dirTreeIdx = indexFromItem(dirTreeModel->index(0, 0), currentDirItem_);
+        auto selModel = ui_->dirTreeView->selectionModel();
         if(dirTreeIdx.isValid()) {
-            auto selModel = ui_->dirTreeView->selectionModel();
             selModel->select(dirTreeIdx, QItemSelectionModel::Select|QItemSelectionModel::Current);
             ui_->dirTreeView->scrollTo(dirTreeIdx);
         }
+        else {
+            selModel->clearSelection();
+        }
     }
 }
 
