@@ -112,6 +112,8 @@ private Q_SLOTS:
 
     void onFileListEnterPressed();
 
+    void onViewsIconSizeTtriggered(QAction *action);
+
     void filter(const QString& text);
 
 private Q_SLOTS:
@@ -156,6 +158,10 @@ private:
 
     void updateUiStates();
 
+    void setViewsIconSize(const int &size);
+
+    void fitFileViewColumns();
+
     std::vector<const FileData*> selectedFiles(bool recursive);
 
     const ArchiverItem* itemFromIndex(const QModelIndex& index);
